@@ -6,8 +6,8 @@ import (
 	"regexp"
 	"strings"
 
-	"github.com/mattn/go-runewidth"
-	"github.com/nsf/termbox-go"
+	runewidth "github.com/mattn/go-runewidth"
+	termbox "github.com/nsf/termbox-go"
 	"github.com/nwidger/jsoncolor"
 )
 
@@ -55,6 +55,7 @@ func (t *Terminal) Draw(attr *TerminalDrawAttributes) error {
 	termbox.Clear(termbox.ColorDefault, termbox.ColorDefault)
 
 	y := t.defaultY
+	_, h := termbox.Size()
 
 	t.drawFilterLine(query, complete)
 
@@ -68,9 +69,13 @@ func (t *Terminal) Draw(attr *TerminalDrawAttributes) error {
 	}
 
 	for idx, cells := range cellsArr {
-		if i := idx - contentOffsetY; i >= 0 {
+		i := idx - contentOffsetY
+		if i >= 0 {
 			t.drawCells(0, i+y, cells)
 		}
+		if i > h {
+			break
+		}
 	}
 
 	termbox.SetCursor(len(t.prompt)+attr.CursorOffset, 0)
@@ -233,7 +238,7 @@ func (t *Terminal) drawCandidates(x int, y int, index int, candidates []string)
 	w, _ := termbox.Size()
 
 	ss := candidates[index]
-	re := regexp.MustCompile("[[:space:]]" + ss + "[[:space:]]")
+	re := regexp.MustCompile("[[:space:]]" + regexp.QuoteMeta(ss) + "[[:space:]]")
 
 	var rows []string
 	var str string
